#!/bin/bash
source  /opt/ros/indigo/setup.bash
source ~/catkin_ws/devel/setup.bash
source ip.sh

#start px4
pushd ~/src/Firmware
make no_sim=1 posix gazebo > /dev/null 2>&1 &
parentpid=`echo $!`
mainpid=`pstree -p $parentpid | sed -rn 's/(.*)(mainapp\()([0-9]*)(.*)/\3/p'`
count=0
#start a 30 second timer to watch for the child process
while [[ -z $mainpid && $count -lt 30 ]]
do
	sleep 1s
	mainpid=`pstree -p $parentpid | sed -rn 's/(.*)(mainapp\()([0-9]*)(.*)/\3/p'`
	count=`expr $count + 1`
done
popd

#start gazebo
# Set the plugin path so Gazebo finds our model and sim
export GAZEBO_PLUGIN_PATH=~/src/Firmware/Tools/sitl_gazebo/Build:${GAZEBO_PLUGIN_PATH}
# Set the model path so Gazebo finds the airframes
export GAZEBO_MODEL_PATH=${GAZEBO_MODEL_PATH}:~/src/Firmware/Tools/sitl_gazebo/models
export SITL_GAZEBO_PATH=~/src/Firmware/Tools/sitl_gazebo
mkdir -p $SITL_GAZEBO_PATH/Build
pushd $SITL_GAZEBO_PATH/Build
cmake -Wno-dev ..
make -j4
#would like to pass ip as an argument...
export GAZEBO_IP=${ip}
export GAZEBO_MASTER_URI=http://${GAZEBO_IP}:11345
popd
count=0
world=''
pushd ../inputs/WORLD
for file in *.world ; do
        if [[ $count -lt 1 ]]; then
        world=$file
        count=`expr $count + 1`
        fi
done
popd
echo ${world}
gzserver -r --record_path ~/simulation/outputs --verbose $SITL_GAZEBO_PATH/worlds/${world}&
SIM_PID=`echo $!`


#start mavros
roslaunch mavros px4.launch fcu_url:="udp://:14540@127.0.0.1:14557"&
rosparent=`echo $!`
rosout=`pstree -p $rosparent | sed -rn 's/(.*)(rosout\()([0-9]*)(.*)/\3/p'`
count=0
#start a 30 second timer to watch for the child process
while [[ -z $rosout && $count -lt 30 ]]
do
	#rosout is the last of the ros processes to launch
        sleep 1s
        rosout=`pstree -p $rosparent | sed -rn 's/(.*)(rosout\()([0-9]*)(.*)/\3/p'`
        count=`expr $count + 1`
done
popd
#the following will already be running if rosout is running
rosmas=`pstree -p $rosparent | sed -rn 's/(.*)(rosmaster\()([0-9]*)(.*)/\3/p'`
mavros=`pstree -p $rosparent | sed -rn 's/(.*)(mavros_node\()([0-9]*)(.*)/\3/p'`

#start rosbag record
#osbag record --all --output-name=../outputs/ros.bag --quiet &
rosbag record /mavros/state /mavros/global_position/local /mavros/local_position/pose /mavros/local_position/velocity /mavros/mission/waypoints --output-name=../outputs/ros.bag --quiet &
bagparentpid=`echo $!`
bagpid=`pstree -p $bagparentpid | sed -rn 's/(.*)(record\()([0-9]*)(.*)/\3/p'`
count=0
start a 30 second timer to watch for the child process
while [[ -z $bagpid && $count -lt 30 ]]
do
	sleep 1s
	bagpid=`pstree -p $bagparentpid | sed -rn 's/(.*)(record\()([0-9]*)(.*)/\3/p'`
	count=`expr $count + 1`
done

touch ../pids/6-$mainpid
touch ../pids/5-$SIM_PID
touch ../pids/4-$mavros
touch ../pids/3-$rosmas
touch ../pids/2-$rosout
touch ../pids/1-$bagpid
